@@ -5,56 +5,56 @@ skip_if_not(broom.helpers::.assert_package("survival", pkg_search = "gtsummary",
 test_that("no errors/warnings with standard use", {
   expect_error(res <- mtcars %>% tbl_summary(by = am) %>% add_overall(), NA)
   expect_warning(mtcars %>% tbl_summary(by = am) %>% add_overall(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_error(res <- mtcars %>% tbl_summary(by = am) %>% add_overall(last = TRUE), NA)
   expect_warning(mtcars %>% tbl_summary(by = am) %>% add_overall(last = TRUE), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_error(res <- iris %>% tbl_summary(by = Species) %>% add_overall(), NA)
   expect_warning(iris %>% tbl_summary(by = Species) %>% add_overall(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 })
 
 test_that("no errors/warnings with missing data", {
   expect_error(res <- survival::lung %>% tbl_summary(by = sex) %>% add_overall(), NA)
   expect_warning(survival::lung %>% tbl_summary(by = sex) %>% add_overall(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_error(res <- survival::lung %>% tbl_summary(by = sex) %>% add_overall(last = TRUE), NA)
   expect_warning(survival::lung %>% tbl_summary(by = sex) %>% add_overall(last = TRUE), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 })
 
 
 test_that("no errors/warnings with standard use for continuous 2", {
   expect_error(res <- mtcars %>% tbl_summary(by = am, type = all_continuous() ~ "continuous2") %>% add_overall(), NA)
   expect_warning(mtcars %>% tbl_summary(by = am, type = all_continuous() ~ "continuous2") %>% add_overall(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_error(res <- mtcars %>% tbl_summary(by = am, type = all_continuous() ~ "continuous2") %>% add_overall(last = TRUE), NA)
   expect_warning(mtcars %>% tbl_summary(by = am, type = all_continuous() ~ "continuous2") %>% add_overall(last = TRUE), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_error(res <- iris %>% tbl_summary(by = Species, type = all_continuous() ~ "continuous2") %>% add_overall(), NA)
   expect_warning(iris %>% tbl_summary(by = Species, type = all_continuous() ~ "continuous2") %>% add_overall(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 })
 
 test_that("no errors/warnings with missing data for continuous 2", {
   expect_error(res <- survival::lung %>% tbl_summary(by = sex, type = all_continuous() ~ "continuous2") %>% add_overall(), NA)
   expect_warning(survival::lung %>% tbl_summary(by = sex, type = all_continuous() ~ "continuous2") %>% add_overall(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_error(res <- survival::lung %>% tbl_summary(by = sex, type = all_continuous() ~ "continuous2") %>% add_overall(last = TRUE), NA)
   expect_warning(survival::lung %>% tbl_summary(by = sex, type = all_continuous() ~ "continuous2") %>% add_overall(last = TRUE), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 })
 
 
 test_that("no errors/warnings with missing data in by variable", {
   expect_error(res <- trial %>% tbl_summary(by = response) %>% add_overall(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 })
 
 test_that("add_overall-works with ordered factors", {
@@ -70,7 +70,7 @@ test_that("add_overall-works with ordered factors", {
       add_overall(),
     NA
   )
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 })
 
 test_that("no errors/warnings with standard use for tbl_svysummary", {
@@ -82,11 +82,11 @@ test_that("no errors/warnings with standard use for tbl_svysummary", {
 
   expect_error(res <- t %>% add_overall(), NA)
   expect_warning(t %>% add_overall(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_error(res <- t %>% add_overall(last = TRUE), NA)
   expect_warning(t %>% add_overall(last = TRUE), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   t <- Titanic %>%
     as.data.frame() %>%
@@ -95,7 +95,7 @@ test_that("no errors/warnings with standard use for tbl_svysummary", {
 
   expect_error(res <- t %>% add_overall(), NA)
   expect_warning(t %>% add_overall(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 })
 
 test_that("no errors/warnings with standard use for tbl_svysummary with continuous2", {
@@ -107,11 +107,11 @@ test_that("no errors/warnings with standard use for tbl_svysummary with continuo
 
   expect_error(res <- t %>% add_overall(), NA)
   expect_warning(t %>% add_overall(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_error(res <- t %>% add_overall(last = TRUE), NA)
   expect_warning(t %>% add_overall(last = TRUE), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   t <- Titanic %>%
     as.data.frame() %>%
@@ -120,7 +120,7 @@ test_that("no errors/warnings with standard use for tbl_svysummary with continuo
 
   expect_error(res <- t %>% add_overall(), NA)
   expect_warning(t %>% add_overall(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 })
 
 test_that("errors produced when expected", {
