@@ -9,7 +9,7 @@ test_that("modify_spanning_header works", {
   expect_snapshot(
     tbl1 %>%
       modify_spanning_header(starts_with("stat_") ~ "**Randomization Assignment**") %>%
-      render_as_html()
+      as.data.frame()
   )
 
   expect_snapshot(
@@ -17,7 +17,7 @@ test_that("modify_spanning_header works", {
       modify_spanning_header(
         label = "Variables", starts_with("stat_") ~ "**Randomization Assignment**"
       ) %>%
-      render_as_html()
+      as.data.frame()
   )
 
   expect_error(
