@@ -21,7 +21,7 @@ test_that("modify_table_body with standard use", {
       modify_header(n_nonevent = "**Control N**", nevent = "**Case N**"),
     NA
   )
-  expect_snapshot(t1 %>% render_as_html())
+  expect_snapshot(t1 %>% as.data.frame())
 
   expect_equal(
     t1[["table_body"]],
