@@ -7,7 +7,7 @@ gts_tbl <-
   add_p()
 
 test_that("no errors/warnings with standard use", {
-  expect_snapshot(separate_p_footnotes(gts_tbl) %>% render_as_html())
+  expect_snapshot(separate_p_footnotes(gts_tbl) %>% as.data.frame())
   expect_error(separate_p_footnotes(mtcars))
 
   expect_error(tbl_split(gts_tbl), NA)
