@@ -5,7 +5,7 @@ test_that("tbl_summary creates output without error/warning (no by var)", {
     lst_tbl <- purrr::map(list(mtcars, iris), ~ tbl_summary(.x, sort = list(all_categorical() ~ "frequency"))),
     NA
   )
-  expect_snapshot(purrr::map(lst_tbl, as_tibble))
+  expect_snapshot(purrr::map(lst_tbl, as.data.frame))
   expect_warning(
     purrr::map(list(mtcars, iris), ~ tbl_summary(.x)),
     NA
@@ -16,7 +16,7 @@ test_that("tbl_summary creates output without error/warning (no by var)", {
 test_that("tbl_summary creates output without error/warning (with by var)", {
   expect_snapshot(
     tbl_summary(mtcars, by = am) %>%
-      render_as_html()
+      as.data.frame()
   )
   expect_warning(
     tbl_summary(mtcars, by = am),
@@ -27,7 +27,7 @@ test_that("tbl_summary creates output without error/warning (with by var)", {
 test_that("tbl_summary allows for named list input", {
   expect_snapshot(
     tbl_summary(mtcars, by = am, label = list(mpg = "New mpg", cyl = "New cyl")) %>%
-      render_as_html()
+      as.data.frame()
   )
   expect_warning(
     tbl_summary(mtcars, by = am, label = list(mpg = "New mpg", cyl = "New cyl")),
@@ -50,7 +50,7 @@ test_that("tbl_summary throws errors/messages with bad 'sort = ' specifications"
 test_that("tbl_summary value argument works properly", {
   expect_snapshot(
     tbl_summary(trial, value = "grade" ~ "III") %>%
-      render_as_html()
+      as.data.frame()
   )
 })
 
@@ -59,11 +59,11 @@ test_that("tbl_summary works in character inputs for `by=`", {
 
   expect_snapshot(
     tbl_summary(trial, by = all_of(my_by_variable)) %>%
-      render_as_html()
+      as.data.frame()
   )
   expect_snapshot(
     tbl_summary(trial, by = "trt") %>%
-      render_as_html()
+      as.data.frame()
   )
   expect_snapshot(
     purrr::map(
@@ -156,7 +156,7 @@ test_that("tbl_summary-testing tidyselect parsing", {
       ),
     NA
   )
-  expect_snapshot(big_test %>% render_as_html())
+  expect_snapshot(big_test %>% as.data.frame())
 
   # checking missing
   expect_equal(
@@ -278,13 +278,13 @@ test_that("tbl_summary-all_categorical() use with `type=`", {
 
 test_that("tbl_summary-difftime does not cause error", {
   expect_snapshot(
-    dplyr::storms %>%
+    df_dplyr_storms %>%
       dplyr::mutate(
         date = ISOdate(year, month, day),
         date_diff = difftime(dplyr::lag(date, 5), date, units = "days")
       ) %>%
       tbl_summary() %>%
-      render_as_html()
+      as.data.frame()
   )
 })
 
@@ -304,18 +304,18 @@ test_that("tbl_summary-all missing data does not cause error", {
     all_missing_no_by <- tbl_summary(df_missing %>% select(-my_by_var)),
     NA
   )
-  expect_snapshot(all_missing_no_by %>% render_as_html())
+  expect_snapshot(all_missing_no_by %>% as.data.frame())
 
   expect_error(
     all_missing_by <- tbl_summary(df_missing, by = my_by_var),
     NA
   )
-  expect_snapshot(all_missing_by %>% render_as_html())
+  expect_snapshot(all_missing_by %>% as.data.frame())
 
   # making categorical, variables that cannot be summarized as categorical
   expect_snapshot(
     tbl_summary(df_missing, by = my_by_var, type = vars(int, dbl) ~ "categorical") %>%
-      render_as_html()
+      as.data.frame()
   )
 
   expect_equal(
@@ -364,12 +364,12 @@ test_that("tbl_summary-all missing data does not cause error", {
   expect_error(
     missing_fct_by <-
       trial %>%
-      mutate(response2 = factor(response) %>% forcats::fct_explicit_na()) %>%
+      mutate(response2 = factor(response) %>% forcats::fct_na_value_to_level(level = "(Missing)")) %>%
       filter(!is.na(response)) %>%
       tbl_summary(by = response2),
     NA
   )
-  expect_snapshot(missing_fct_by %>% render_as_html())
+  expect_snapshot(missing_fct_by %>% as.data.frame())
 
   expect_equal(
     missing_fct_by$table_body %>% select(starts_with("stat_")) %>% names(),
@@ -383,7 +383,7 @@ test_that("tbl_summary-no error when *data frame* with single column passed", {
     trial["trt"] %>%
       as.data.frame() %>%
       tbl_summary(label = trt ~ "TREATMENT GROUP") %>%
-      render_as_html()
+      as.data.frame()
   )
 })
 
@@ -393,7 +393,7 @@ test_that("tbl_summary-no error when by variable is ordered factor", {
     trial %>%
       dplyr::mutate(grade = as.ordered(grade)) %>%
       tbl_summary(by = grade) %>%
-      render_as_html()
+      as.data.frame()
   )
 })
 
@@ -402,7 +402,7 @@ test_that("tbl_summary- works with grouped data (it ungroups it first)", {
     trial %>% dplyr::group_by(response) %>%
       dplyr::select(response, death, trt) %>%
       tbl_summary(by = trt) %>%
-      render_as_html()
+      as.data.frame()
   )
 })
 
@@ -415,7 +415,7 @@ test_that("tbl_summary-works with ordered factors", {
         ~ factor(., ordered = TRUE)
       ) %>%
       tbl_summary(by = trt) %>%
-      render_as_html()
+      as.data.frame()
   )
 })
 
@@ -472,7 +472,7 @@ test_that("tbl_summary creates output without error/warning for continuous2 (no
 test_that("tbl_summary creates output without error/warning for continuous2 (with by var)", {
   expect_snapshot(
     tbl_summary(mtcars, by = am, type = all_continuous() ~ "continuous2") %>%
-      render_as_html()
+      as.data.frame()
   )
   expect_warning(
     tbl_summary(mtcars, by = am, type = all_continuous() ~ "continuous2"),
@@ -507,7 +507,7 @@ test_that("tbl_summary(digits=) tests with fn inputs", {
       ),
     NA
   )
-  expect_snapshot(tbl_digits %>% render_as_html())
+  expect_snapshot(tbl_digits %>% as.data.frame())
 
   # checking the display is correct
   expect_equal(
@@ -546,14 +546,14 @@ test_that("tbl_summary() continuous vars with cat summary vars only", {
     tbl1 <- trial %>% select(age) %>% tbl_summary(statistic = age ~ "{N_obs}"),
     NA
   )
-  expect_snapshot(tbl1 %>% render_as_html())
+  expect_snapshot(tbl1 %>% as.data.frame())
   expect_equal(tbl1$table_body$stat_0, c("200", "11"))
 
   expect_error(
     tbl2 <- trial %>% select(age, trt) %>% tbl_summary(by = trt, statistic = age ~ "{N_obs}"),
     NA
   )
-  expect_snapshot(tbl2 %>% render_as_html())
+  expect_snapshot(tbl2 %>% as.data.frame())
   expect_equal(tbl2$meta_data$df_stats %>% pluck(1, "N_obs"), c(98, 102),
     ignore_attr = TRUE
   )
@@ -571,7 +571,7 @@ test_that("tbl_summary() works with date and date/time", {
     tbl1 <- df_date %>% tbl_summary(),
     NA
   )
-  expect_snapshot(tbl1 %>% render_as_html())
+  expect_snapshot(tbl1 %>% as.data.frame())
 
   expect_equal(
     tbl1 %>% as_tibble() %>% select(last_col()) %>% dplyr::pull(),
@@ -583,7 +583,7 @@ test_that("tbl_summary() works with date and date/time", {
     tbl1 <- df_date %>% select(-group) %>% tbl_summary(type = everything() ~ "continuous", digits = everything() ~ month_year),
     NA
   )
-  expect_snapshot(tbl1 %>% render_as_html())
+  expect_snapshot(tbl1 %>% as.data.frame())
 
   expect_equal(
     tbl1 %>% as_tibble() %>% select(last_col()) %>% dplyr::pull(),
@@ -594,13 +594,13 @@ test_that("tbl_summary() works with date and date/time", {
     tbl1 <- df_date %>% tbl_summary(by = group, type = everything() ~ "continuous", digits = everything() ~ month_year),
     NA
   )
-  expect_snapshot(tbl1 %>% render_as_html())
+  expect_snapshot(tbl1 %>% as.data.frame())
 
   expect_error(
     tbl2 <- df_date %>% tbl_summary(by = group),
     NA
   )
-  expect_snapshot(tbl2 %>% render_as_html())
+  expect_snapshot(tbl2 %>% as.data.frame())
 })
 
 
@@ -653,7 +653,7 @@ test_that("no error when by variable omitted from include", {
   expect_snapshot(
     trial %>%
       tbl_summary(by = trt, include = age) %>%
-      render_as_html()
+      as.data.frame()
   )
 })
 
@@ -662,14 +662,14 @@ test_that("all column names are accepted", {
 
   expect_snapshot(
     tbl_summary(df, by = "variable") %>%
-      render_as_html()
+      as.data.frame()
   )
-  expect_snapshot(tbl_summary(df) %>% render_as_html())
+  expect_snapshot(tbl_summary(df) %>% as.data.frame())
   expect_snapshot(
-    tbl_summary(df %>% dplyr::rename(by = variable)) %>% render_as_html()
+    tbl_summary(df %>% dplyr::rename(by = variable)) %>% as.data.frame()
   )
   expect_snapshot(
-    tbl_summary(df %>% dplyr::rename(by = variable), by = "by") %>% render_as_html()
+    tbl_summary(df %>% dplyr::rename(by = variable), by = "by") %>% as.data.frame()
   )
 })
 
@@ -784,6 +784,6 @@ test_that("no error when data frame contains named vector", {
     )
 
   expect_snapshot(
-    tbl_summary(df, type = list(everything() ~ "continuous")) %>% render_as_html()
+    tbl_summary(df, type = list(everything() ~ "continuous")) %>% as.data.frame()
   )
 })
